@@ -55,7 +55,12 @@ public:
 
     void savePassword(const QString &password);
 
+public Q_SLOTS:
+    void scaleResize(int w, int h) override;
+
 protected:
+    QSize initialSize();
+
     void paintEvent(QPaintEvent *event) override;
 
     void keyPressEvent(QKeyEvent *event) override;
@@ -63,6 +68,7 @@ protected:
 
     void mousePressEvent(QMouseEvent *event) override;
     void mouseReleaseEvent(QMouseEvent *event) override;
+    void mouseDoubleClickEvent(QMouseEvent *event) override;
     void mouseMoveEvent(QMouseEvent *event) override;
 
     void wheelEvent(QWheelEvent * event) override;
